# Example: Closed-Loop Behavioral Study

For a detailed example of setting up a closed-loop behavioral study with an online experiment, see the [Basic Closed-Loop Psychophysics Study](../../examples/closed-loop-basic/index.md).
